#
# spec file for package osmo-fl2k
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover	0
%define libname libosmo-fl2k%{sover}
Name:           osmo-fl2k
Version:        0.2.0+git.20231103
Release:        1.1
Summary:        SDR driver for FL2000 based USB 3.0 to VGA adapters
License:        GPL-2.0-or-later
Group:          Productivity/Hamradio/Other
URL:            https://osmocom.org/projects/osmo-fl2k/wiki
#Git-Clone:     https://git.osmocom.org/osmo-fl2k
Source:         %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  git-core
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Osmo-fl2k allows to use USB 3.0 to VGA adapters based on the
Fresco Logic FL2000 chip as general purpose DACs and SDR transmitter
generating a continuous stream of samples by avoiding the HSYNC and
VSYNC blanking intervals.

%package -n %{libname}
Summary:        SDR driver for FL2000 based USB to VGA adapters
Group:          System/Libraries
Requires:       %{name}-udev

%description -n %{libname}
Osmo-fl2k allows to use USB 3.0 to VGA adapters based on the
Fresco Logic FL2000 chip as general purpose DACs and SDR transmitter
generating a continuous stream of samples by avoiding the HSYNC and
VSYNC blanking intervals.

%package udev
Summary:        Udev rules for osmo-fl2k
Group:          Hardware/Other

%description udev
Udev rules for osmo-fl2k.

%package devel
Summary:        Development files for osmo-fl2k
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Library headers for osmo-fl2k driver.

%prep
%setup -q

%build
%cmake \
    -DINSTALL_UDEV_RULES=ON \
    -DUDEV_RULES_PATH=%{_udevrulesdir}
make %{?_smp_mflags}

%install
%cmake_install
rm %{buildroot}%{_libdir}/libosmo-fl2k.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license COPYING
%doc AUTHORS README.md
%{_bindir}/fl2k_file
%{_bindir}/fl2k_fm
%{_bindir}/fl2k_tcp
%{_bindir}/fl2k_test

%files -n %{libname}
%{_libdir}/libosmo-fl2k.so.%{sover}*

%files udev
%{_udevrulesdir}/osmo-fl2k.rules

%files devel
%{_libdir}/libosmo-fl2k.so
%{_includedir}/osmo-fl2k.h
%{_includedir}/osmo-fl2k_export.h
%{_libdir}/pkgconfig/libosmo-fl2k.pc

%changelog
* Fri Nov  3 2023 mardnh@gmx.de
- Update to version 0.2.0+git.20231103:
  * Release 0.2.0
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.1.1+git.20200602:
  * lib: revert implementing RGB233 mode
  * lib: fix hang on exit
  * lib: reuse hint message when zero-copy buffer alloc fails
  * lib: fixed rgb332 macros
  * lib: added utility macros for rgb332 mode
  * lib: implement enabling RGB332 mode
  * lib: fall back to iface 1 in case iface 0 altsetting 1 fails
  * lib: use interface 0 altsetting 1 instead of interface 1
  * set CMake policy CMP0075 if it exists
  * fix compiler warnings
  * fl2k_tcp: don't free buffer while lib still uses it
  * improve exit handling on device removal
  * lib: wait for sample worker thread before freeing buffers
  * fl2k_file: check read return value before repeating
  * fl2k_fm: make inline functions static
  * contrib/jenkins.sh: osmo-fl2k build verification
  * lib: Add workaround for Linux usbfs mmap() bug
  * lib: add I2C support
  * fix sleep durations on Windows
  * debian: build-dep on dh-autoreconf for Ubuntu 16.04/Debian8
  * debian: Attempt to down-grade the debhelper version requirement
  * Add Debian packaging information
  * enable multiarch build by means of GNUInstallDirs
  * libusb-1.0.22 deprecated libusb_set_debug() with
    libusb_set_option()
  * fl2k_file: support reading from stdin
  * lib: update output on zero-copy allocation
  * lib: free zero-copy buffers in case of error
* Sat Apr 28 2018 mardnh@gmx.de
- Update to version 0.1.1+git.20180428:
  * fl2k_test: fix build on Mac OS
  * fl2k_fm: add missing help text for stereo and rds
  * update version to 0.1.1
  * set version to 0.1git
* Tue Apr 24 2018 mardnh@gmx.de
- Update to version 0.1.0+git.20180424:
  * Fix build with MinGW
  * CMake: Make UDEV_RULES_PATH configurable
* Tue Apr 24 2018 mardnh@gmx.de
- Update to version 0.0.0+git.20180423:
  * fl2k_fm: add SPDX identifier
  * lib: libusb_dev_mem_free() is not present in old versions
* Sun Apr 22 2018 mardnh@gmx.de
- Initial package, version 0.0.0+git.20180419
